# Configure paths for libmutils
# Owen Taylor     97-11-3

dnl AM_PATH_LIBMUTILS([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl Test for LIBMUTILS, and define LIBMUTILS_CFLAGS and LIBMUTILS_LIBS
dnl
AC_DEFUN(AM_PATH_LIBMUTILS,
[dnl 
dnl Get the cflags and libraries from the mutils-config script
dnl
AC_ARG_WITH(libmutils-prefix,[  --with-libmutils-prefix=PFX   Prefix where libmutils is installed (optional)],
            libmutils_prefix="$withval", libmutils_prefix="")
AC_ARG_WITH(libmutils-exec-prefix,[  --with-libmutils-exec-prefix=PFX Exec prefix where libmutils is installed (optional)],
            libmutils_exec_prefix="$withval", libmutils_exec_prefix="")
AC_ARG_ENABLE(libmutilstest, [  --disable-libmutilstest       Do not try to compile and run a test libmutils program],
            , enable_libmutilstest=yes)


  if test x$libmutils_exec_prefix != x ; then
     libmutils_args="$libmutils_args --exec-prefix=$libmutils_exec_prefix"
     if test x${LIBMUTILS_CONFIG+set} != xset ; then
        LIBMUTILS_CONFIG=$libmutils_exec_prefix/bin/mutils-config
     fi
  fi
  if test x$libmutils_prefix != x ; then
     libmutils_args="$libmutils_args --prefix=$libmutils_prefix"
     if test x${LIBMUTILS_CONFIG+set} != xset ; then
        LIBMUTILS_CONFIG=$libmutils_prefix/bin/mutils-config
     fi
  fi

  AC_PATH_PROG(LIBMUTILS_CONFIG, mutils-config, no)
	
  min_libmutils_version=ifelse([$1], ,0.1.0,$1)
  AC_MSG_CHECKING([for libmutils - version >= $min_libmutils_version])
  no_libmutils=""
  if test "$LIBMUTILS_CONFIG" = "no" ; then
    no_libmutils=yes
  else
		AC_LANG_SAVE
		AC_LANG_CPLUSPLUS

    LIBMUTILS_CFLAGS=`$LIBMUTILS_CONFIG $libmutils_args --cflags`
    LIBMUTILS_LIBS=`$LIBMUTILS_CONFIG $libmutils_args --libs`
    libmutils_major_version=`$LIBMUTILS_CONFIG $libmutils_args --version | \
           sed 's/[[^0-9]]*\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    libmutils_libmutils_version=`$LIBMUTILS_CONFIG $libmutils_args --version | \
           sed 's/[[^0-9]]*\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    libmutils_micro_version=`$LIBMUTILS_CONFIG $libmutils_args --version | \
           sed 's/[[^0-9]]*\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`

    if test "x$enable_libmutilstest" = "xyes" ; then
      ac_save_CFLAGS="$CFLAGS"
      ac_save_LIBS="$LIBS"
      CFLAGS="$CFLAGS $LIBMUTILS_CFLAGS"
      LIBS="$LIBMUTILS_LIBS $LIBS"
dnl
dnl Now check if the installed libmutils is sufficiently new. (Also sanity
dnl checks the results of mutils-config to some extent
dnl
      rm -f conf.libmutilstest
      AC_TRY_RUN([
#include <libmutils.h>
#include <stdio.h>
#include <stdlib.h>

char *my_strdup(char *str)
{
	char *new_str;

	if (str)
	{
		new_str = (char *)malloc((strlen(str) + 1) * sizeof(char));
		strcpy(new_str, str);
	}
	else
		new_str = NULL;
	
	return new_str;
}

int 
main ()
{
  int major, libmutils, micro;
  char *tmp_version;

  system ("touch conf.libmutilstest");

  /* HP/UX 9 (%@#!) writes to sscanf strings */
  tmp_version = my_strdup("$min_libmutils_version");
  if (sscanf(tmp_version, "%d.%d.%d", &major, &libmutils, &micro) != 3) {
     printf("%s, bad version string\n", "$min_libmutils_version");
     exit(1);
   }

  if (($libmutils_major_version  > major) ||
     (($libmutils_major_version == major) && ($libmutils_libmutils_version > libmutils)) ||
     (($libmutils_major_version == major) && ($libmutils_libmutils_version == libmutils) &&
      ($libmutils_micro_version >= micro)))
    {
			return 0;
		}
		else
		{
      printf("\n*** 'mutils-config --version' returned %d.%d.%d, but libmutils (%d.%d.%d)\n", 
             $libmutils_major_version, $libmutils_libmutils_version, $libmutils_micro_version,
             major, libmutils, micro);
      printf ("*** was found! If mutils-config was correct, then it is best\n");
      printf ("*** to remove the old version of libmutils. You may also be able to fix the error\n");
      printf("*** by modifying your LD_LIBRARY_PATH enviroment variable, or by editing\n");
      printf("*** /etc/ld.so.conf. Make sure you have run ldconfig if that is\n");
      printf("*** required on your system.\n");
      printf("*** If mutils-config was wrong, set the environment variable LIBMUTILS_CONFIG\n");
      printf("*** to point to the correct copy of mutils-config, and remove the file config.cache\n");
      printf("*** before re-running configure\n");
			return 1;
    } 
}
],, no_libmutils=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
       CFLAGS="$ac_save_CFLAGS"
       LIBS="$ac_save_LIBS"
     fi
  fi
  if test "x$no_libmutils" = x ; then
     AC_MSG_RESULT(yes)
     ifelse([$2], , :, [$2])     
  else
     AC_MSG_RESULT(no)
     if test "$LIBMUTILS_CONFIG" = "no" ; then
       echo "*** The mutils-config script installed by libmutils could not be found"
       echo "*** If libmutils was installed in PREFIX, make sure PREFIX/bin is in"
       echo "*** your path, or set the LIBMUTILS_CONFIG environment variable to the"
       echo "*** full path to mutils-config."
     else
       if test -f conf.libmutilstest ; then
        :
       else
          echo "*** Could not run libmutils test program, checking why..."
          CFLAGS="$CFLAGS $LIBMUTILS_CFLAGS"
          LIBS="$LIBS $LIBMUTILS_LIBS"
          AC_TRY_LINK([
#include <libmutils.h>
#include <stdio.h>
],      [ return ((libmutils_major_version) || (libmutils_libmutils_version) || (libmutils_micro_version)); ],
        [ echo "*** The test program compiled, but did not run. This usually means"
          echo "*** that the run-time linker is not finding libmutils or finding the wrong"
          echo "*** version of libmutils. If it is not finding libmutils, you'll need to set your"
          echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
          echo "*** to the installed location  Also, make sure you have run ldconfig if that"
          echo "*** is required on your system"
          echo "***"
          echo "*** If you have an old version installed, it is best to remove it, although"
          echo "*** you may also be able to get things to work by modifying LD_LIBRARY_PATH"
          echo "***"
          echo "*** If you have a RedHat 5.0 system, you should remove the libmutils package that"
          echo "*** came with the system with the command"
          echo "***"
          echo "***    rpm --erase --nodeps libmutils libmutils-devel" ],
        [ echo "*** The test program failed to compile or link. See the file config.log for the"
          echo "*** exact error that occured. This usually means libmutils was incorrectly installed"
          echo "*** or that you have moved libmutils since it was installed. In the latter case, you"
          echo "*** may want to edit the mutils-config script: $LIBMUTILS_CONFIG" ])
          CFLAGS="$ac_save_CFLAGS"
          LIBS="$ac_save_LIBS"
       fi
     fi
     LIBMUTILS_CFLAGS=""
     LIBMUTILS_LIBS=""
     ifelse([$3], , :, [$3])
		 AC_LANG_RESTORE
  fi
  AC_SUBST(LIBMUTILS_CFLAGS)
  AC_SUBST(LIBMUTILS_LIBS)
  rm -f conf.libmutilstest
])
