dnl # $Id: libpql.m4,v 1.1.1.1 2001/08/04 19:35:59 chipx86 Exp $
dnl # Configure paths for liblibpql

dnl AM_PATH_PQL([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl Test for PQL, and define PQL_CFLAGS and PQL_LIBS
dnl
AC_DEFUN(AM_PATH_PQL,
[dnl
dnl Get the cflags and libraries from the pql-config script
dnl
AC_ARG_WITH(libpql-prefix,[  --with-libpql-prefix=PFX  Prefix where libpql is installed (optional)],
		libpql_config_prefix="$withval", libpql_config_prefix="")
AC_ARG_WITH(libpql-exec-prefix,[  --with-libpql-exec-prefix=PFX  Exec prefix where libpql is installed (optional)],
		libpql_config_exec_prefix="$withval", libpql_config_exec_prefix="")
AC_ARG_ENABLE(libpqltest, [  --disable-libpqltest  Do not try to compile and run a test libpql program],
		, enable_libpqltest=yes)

	if test x$libpql_config_exec_prefix != x ; then
		libpql_config_args="$libpql_config_args --exec-prefix=$libpql_config_exec_prefix"
		if test x${PQL_CONFIG+set} != xset ; then
			PQL_CONFIG=$libpql_config_exec_prefix/bin/pql-config
		fi
	fi
	if test x$libpql_config_prefix != x ; then
		libpql_config_args="$libpql_config_args --prefix=$libpql_config_prefix"
		if test x${PQL_CONFIG+set} != xset ; then
			PQL_CONFIG=$libpql_config_prefix/bin/pql-config
		fi
	fi

	AC_PATH_PROG(PQL_CONFIG, pql-config, no)

	min_libpql_version=ifelse([$1], , 0.1.0, $1)
	AC_MSG_CHECKING([for libpql - version >= $min_libpql_version])
	no_libpql=""
	if test "$PQL_CONFIG" = "no" ; then
		no_libpql=yes
	else
		PQL_CFLAGS=`$PQL_CONFIG $libpql_config_args --cflags`
		PQL_LIBS=`$PQL_CONFIG $libpql_config_args --libs`
		libpql_config_major_version=`$PQL_CONFIG $libpql_config_args --version | \
			sed 's/[[^0-9]]*\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
		libpql_config_minor_version=`$PQL_CONFIG $libpql_config_args --version | \
			sed 's/[[^0-9]]*\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
		libpql_config_micro_version=`$PQL_CONFIG $libpql_config_args --version | \
			sed 's/[[^0-9]]*\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`
		if test "x$enable_libpqltest" = "xyes" ; then
			ac_save_CFLAGS="$CFLAGS"
			ac_save_LIBS="$LIBS"
			CFLAGS="$CFLAGS $PQL_CFLAGS"
			LIBS="$PQL_LIBS $LIBS"
dnl
dnl Now check if the installed libpql is sufficiently new.
dnl (Also sanity checks the results of pql-config to some extent.)
dnl
			rm -f conf.libpqltest
			AC_TRY_RUN([
#include <pql-config.h>
#include <stdio.h>
#include <stdlib.h>

char *my_strdup(char *str)
{
	char *new_str;

	if (str)
	{
		new_str = (char *)malloc((strlen(str) + 1) * sizeof(char));
		strcpy(new_str, str);
	}
	else
		new_str = NULL;

	return new_str;
}

int main()
{
	int major, minor, micro;
	char *tmp_version;

	system("touch conf.libpqltest");

	/* HP/UX 9 (%@#!) writes to sscanf strings */
	tmp_version = my_strdup("$min_libpql_version");
	if (sscanf(tmp_version, "%d.%d.%d", &major, &minor,&micro) != 3) {
		printf("%s, bad version string\n", "$min_libpql_version");
		exit(1);
	}

	if (($libpql_config_major_version  > major) ||
	   (($libpql_config_major_version == major) && ($libpql_config_minor_version  > minor)) ||
	   (($libpql_config_major_version == major) && ($libpql_config_minor_version == minor) &&
	    ($libpql_config_micro_version >= micro)))
	{
		return 0;
	}
	else
	{
		printf("\n*** 'pql-config --version' returned%d.%d.%d, but libpql (%d.%d.%d)\n",
		       $libpql_config_major_version, $libpql_config_minor_version, $libpql_config_micro_version,
		       major, minor, micro);
		printf("*** was found! If pql-config was correct, then it is best\n");
		printf("*** to remove the old version of libpql. You may also be able to fix the error\n");
		printf("*** by modifying your LD_LIBRARY_PATH environment variable, or by editing\n");
		printf("*** /etc/ld.so.conf. Make sure you have run ldconfig if that is\n");
		printf("*** required on your system.\n");
		printf("*** If pql-config was wrong, set the environment variable PQL_CONFIG\n");
		printf("*** to point to the correct copy of pql-config, and remove the file config.cache\n");
		printf("*** before re-running configure.\n");
		return 1;
	}
}
],, no_libpql=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
			CFLAGS="$ac_save_CFLAGS"
			LIBS="$ac_save_LIBS"
		fi
	fi
	if test "x$no_libpql" = x ; then
		AC_MSG_RESULT(yes)
		ifelse([$2], , :, [$2])
	else
		AC_MSG_RESULT(no)
		if test "$PQL_CONFIG" = "no" ; then
			echo "*** The pql-config script installed by libpql could not be found"
			echo "*** If libpql was installed in PREFIX, make sure PREFIX/bin is in"
			echo "*** your path, or set the PQL_CONFIG environment variable to the "
			echo "*** full path to pql-config."
		else
			if test -f conf.libpqltest ; then
				:
			else
				echo "*** Could not run libpql test program, checking why..."
				CFLAGS="$CFLAGS $PQL_CFLAGS"
				LIBS="$LIBS $PQL_LIBS"
				AC_TRY_LINK([
#include <pql-config.h>
#include <stdio.h>
],[
				return ((libpql_major_version) || (libpql_minor_version) || (libpql_micro_version));
],[
				echo "*** The test program compiled, but did not run. This usually means"
				echo "*** that the run-time linker is not finding libpql or finding the wrong"
				echo "*** version of libpql. If it is not finding libpql, you'll need to set your"
				echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
				echo "*** to the installed location. Also, make sure you have run ldconfig, if that"
				echo "*** is required on your system."
				echo "***"
				echo "*** If you have an old version installed, it is best to remove it, although"
				echo "*** you may also be able to get things to work by modifying LD_LIBRARY_PATH."
				])
				CFLAGS="$ac_save_CFLAGS"
				LIBS="$ac_save_LIBS"
			fi
		fi
		PQL_CFLAGS=""
		PQL_LIBS=""
		ifelse([$3], , :, [$3])
	fi
	AC_SUBST(PQL_CFLAGS)
	AC_SUBST(PQL_LIBS)
	rm -f conf.libpqltest
])
