/**
 * @file dialog.h Dialog functions
 *
 * $Id: dialog.h,v 1.7 2001/12/31 09:26:54 chipx86 Exp $
 *
 * @Copyright (C) 2000-2002 The GNUpdate Project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#ifndef _GENST_DIALOG_H_
#define _GENST_DIALOG_H_

#include "genst.h"

/**************************************************************************
 * ListItem, DialogList
 **************************************************************************/
typedef struct _ListItem ListItem;

typedef struct
{
	char *title;
	char *text;
	int count;

	ListItem *items;
	ListItem *lastItem;

} DialogList;

struct _ListItem
{
	char *name;
	char *description;
	char on;

	ListItem *prev;
	ListItem *next;
};


/**************************************************************************
 * DialogMenu, MenuItem
 **************************************************************************/
typedef struct _MenuItem MenuItem;

typedef struct
{
	char *title;
	char *text;
	char *defaultSelection;
	int count;

	MenuItem *items;
	MenuItem *lastItem;

} DialogMenu;

struct _MenuItem
{
	char *name;
	char *description;

	MenuItem *prev;
	MenuItem *next;
};

/**************************************************************************
 * Gauge
 **************************************************************************/
typedef struct
{
	FILE *stream;
	
} Gauge;

/**************************************************************************
 * General dialog functions
 **************************************************************************/
int dialog(char **result, const char *type, const char *title,
		   const char *text, const char *params);

void  dialogMsgBox(const char *text);
char  dialogYesNo(const char *title, const char *text);
char *dialogInputBox(const char *title, const char *text,
					 const char *defaultValue);


/**************************************************************************
 * Dialog List
 **************************************************************************/
DialogList *newDialogList(const char *title, const char *text);
void freeDialogList(DialogList *list);
void dialogListAddItem(DialogList *list, ListItem *item);

int dialogRenderCheckList(DialogList *list, char ***result);
char *dialogRenderRadioList(DialogList *list);


/**************************************************************************
 * List Item
 **************************************************************************/
ListItem *newDialogListItem(const char *name, const char *description,
							char on);
void freeDialogListitem(ListItem *item);


/**************************************************************************
 * Menu
 **************************************************************************/
DialogMenu *newDialogMenu(const char *title, const char *text);
void freeDialogMenu(DialogMenu *menu);
void dialogAddMenuItem(DialogMenu *menu, MenuItem *item);
void dialogAddMenuSep(DialogMenu *menu);
void dialogSetMenuDefault(DialogMenu *menu, const char *defaultSelection);

char *dialogRenderMenu(DialogMenu *menu);

/**************************************************************************
 * MenuItem
 **************************************************************************/
MenuItem *newDialogMenuItem(const char *name, const char *description);
void freeDialogMenuItem(MenuItem *item);

/**************************************************************************
 * Gauge
 **************************************************************************/
Gauge *newDialogGauge(const char *title, const char *text);
void freeDialogGauge(Gauge *gauge);
void dialogStopGauge(Gauge *gauge);
void dialogUpdateGauge(Gauge *gauge, int pct, char *text);

#endif /* _GENST_DIALOG_H_ */
