/**
 * @file generateAutogen.c autogen.sh generation
 * 
 * $Id: generate_autogen.c,v 1.6 2001/12/31 09:26:54 chipx86 Exp $
 *
 * @Copyright (C) 2000-2002 The GNUpdate Project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#include "genst.h"

void
generateAutogen(ProjectInfo *project, GenerationState *state)
{
	char *filename;
	FILE *f;
	
	updateGenerationStatus(state, "Creating:\n\t", "autogen.sh");

	filename = (char *)malloc((strlen(project->dir) + 12) * sizeof(char));
	
	strcpy(filename, project->dir);
	strcat(filename, "/autogen.sh");

	if ((f = fopen(filename, "w")) == NULL)
	{
		fprintf(stderr, "Could not write to %s\n", filename);
		exit(1);
	}

	fprintf(f, "#!/bin/sh\n");
	fprintf(f, "# Run this to generate all the initial makefiles, etc.\n");
	fprintf(f, "# $" "Id" "$\n\n");
	fprintf(f, "DIE=0\n\n");
	fprintf(f, "echo \"Generating configuration files for %s,"
			   " please wait...\"\n\n", project->name);

	fprintf(f, "(autoconf --version) < /dev/null > /dev/null 2>&1 || {\n");
	fprintf(f, "\techo\n");
	fprintf(f, "\techo \"You must have autoconf installed to compile %s.\"\n",
			project->name);
	fprintf(f, "\techo \"Download the appropriate package for your"
			   " distribution,\"\n");
	fprintf(f, "\techo \"or get the source tarball at"
			   " ftp://ftp.gnu.org/pub/gnu/\"\n");
	fprintf(f, "\tDIE=1\n");
	fprintf(f, "}\n\n");

	if (project->target == TARGET_BOTH || project->target == TARGET_LIBRARY)
	{
		fprintf(f, "(libtool --version) < /dev/null > /dev/null 2>&1 || {\n");
		fprintf(f, "\techo\n");
		fprintf(f, "\techo \"You must have libtool installed to"
				   " compile %s.\"\n", project->name);
		fprintf(f, "\techo \"Download the appropriate package for your"
				   " distribution,\"\n");
		fprintf(f, "\techo \"or get the source tarball at"
				   " ftp://ftp.gnu.org/pub/gnu/\"\n");
		fprintf(f, "\tDIE=1\n");
		fprintf(f, "}\n\n");
	}

	fprintf(f, "(automake --version) < /dev/null > /dev/null 2>&1 || {\n");
	fprintf(f, "\techo\n");
	fprintf(f, "\techo \"You must have automake installed to compile %s.\"\n",
			project->name);
	fprintf(f, "\techo \"Download the appropriate package for your"
			   " distribution,\"\n");
	fprintf(f, "\techo \"or get the source tarball at"
			   " ftp://ftp.gnu.org/pub/gnu/\"\n");
	fprintf(f, "\tDIE=1\n");
	fprintf(f, "}\n\n");

	fprintf(f, "[ $DIE -eq 1 ] && exit 1;\n\n");


	if (project->target == TARGET_BOTH || project->target == TARGET_LIBRARY)
	{
		fprintf(f, "echo \"  libtoolize --copy --force\"\n");
		fprintf(f, "libtoolize --copy --force\n");
	}

	fprintf(f, "echo \"  aclocal $ACLOCAL_FLAGS\"\n");
	fprintf(f, "aclocal $ACLOCAL_FLAGS\n");
	fprintf(f, "echo \"  autoheader\"\n");
	fprintf(f, "autoheader\n");
	fprintf(f, "echo \"  automake --add-missing\"\n");
	fprintf(f, "automake --add-missing\n");
	fprintf(f, "echo \"  autoconf\"\n");
	fprintf(f, "autoconf\n\n");

	fprintf(f, "if [ -x config.status -a -z \"$*\" ]; then\n");
	fprintf(f, "\t./config.status --recheck\n");
	fprintf(f, "else\n");
	fprintf(f, "\tif test -z \"$*\"; then\n");
	fprintf(f, "\t\techo \"I am going to run ./configure with no arguments -"
			   " if you wish\"\n");
	fprintf(f, "\t\techo \"to pass any to it, please specify them on the $0 "
			   " command line.\"\n");
	fprintf(f, "\t\techo \"If you do not wish to run ./configure, press "
			   " Ctrl-C now.\"\n");
	fprintf(f, "\t\ttrap 'echo \"configure aborted\" ; exit 0' 1 2 15\n");
	fprintf(f, "\t\tsleep 1\n");
	fprintf(f, "\tfi\n");
	fprintf(f, "\t./configure \"$@\";\n");
	fprintf(f, "fi\n");

	fclose(f);

	chmod(filename, 0755);

	free(filename);
}

