/**
 * @file generateLibConfig.c Library -config script generation
 * 
 * $Id: generate_libconfig.c,v 1.6 2001/12/31 09:26:55 chipx86 Exp $
 *
 * @Copyright (C) 2000-2002 The GNUpdate Project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#include "genst.h"

void
generateLibConfig(ProjectInfo *project, GenerationState *state)
{
	Package *pkg;
	Check   *check;
	char *filename;
	FILE *f;

	if (project->target != TARGET_BOTH && project->target != TARGET_LIBRARY)
		return;

	filename = (char *)malloc((strlen(project->name) + 11) * sizeof(char));
	
	sprintf(filename, "%s-config.in", project->name);
	updateGenerationStatus(state, "Creating:\n\t", filename);

	free(filename);

	filename = (char *)malloc((strlen(project->dir) + strlen(project->name) +
							   12) * sizeof(char));

	sprintf(filename, "%s/%s-config.in", project->dir, project->name);

	if ((f = fopen(filename, "w")) == NULL)
	{
		fprintf(stderr, "Could not write to %s\n", filename);
		exit(1);
	}

	free(filename);

	fprintf(f, "#!/bin/sh\n\n");
	fprintf(f, "prefix=@prefix@\n");
	fprintf(f, "exec_prefix=@prefix@\n");
	fprintf(f, "exec_prefix_set=no\n\n");
	fprintf(f, "usage=\"\\\n");
	fprintf(f, "Usage: %s-config [--prefix[=DIR]] [--exec-prefix[=DIR]]"
			   " [--version] [--libs] [--cflags]\"\n\n", project->name);
	
	fprintf(f, "if test $# -eq 0; then\n");
	fprintf(f, "\techo \"${usage}\" 1>&2\n");
	fprintf(f, "\texit 1\n");
	fprintf(f, "fi\n\n");

	fprintf(f, "while test $# -gt 0; do\n");
	fprintf(f, "\tcase \"$1\" in\n");
	fprintf(f, "\t\t-*=*) optarg=`echo \"$1\" |"
			   " sed 's/[-_a-zA-Z0-9]*=//'` ;;\n");
	fprintf(f, "\t\t*) optarg= ;;\n");
	fprintf(f, "\tesac\n\n");
	
	fprintf(f, "\tcase $1 in\n");
	fprintf(f, "\t\t--prefix=*)\n");
	fprintf(f, "\t\t\tprefix=$optarg\n");
	fprintf(f, "\t\t\tif test $exec_prefix_set = no ; then\n");
	fprintf(f, "\t\t\t\texec_prefix=$optarg\n");
	fprintf(f, "\t\t\tfi\n");
	fprintf(f, "\t\t\t;;\n\n");

	fprintf(f, "\t\t--prefix)\n");
	fprintf(f, "\t\t\techo $prefix\n");
	fprintf(f, "\t\t\t;;\n\n");

	fprintf(f, "\t\t--exec-prefix=*)\n");
	fprintf(f, "\t\t\texec_prefix=$optarg\n");
	fprintf(f, "\t\t\texec_prefix_set=yes\n");
	fprintf(f, "\t\t\t;;\n\n");

	fprintf(f, "\t\t--exec-prefix)\n");
	fprintf(f, "\t\t\techo $exec_prefix\n");
	fprintf(f, "\t\t\t;;\n\n");

	fprintf(f, "\t\t--version)\n");
	fprintf(f, "\t\t\techo @VERSION@\n");
	fprintf(f, "\t\t\t;;\n\n");

	fprintf(f, "\t\t--cflags)\n");
	fprintf(f, "\t\t\tif test @includedir@ != /usr/include ; then\n");
	fprintf(f, "\t\t\t\tincludes=-I@includedir@\n");
	fprintf(f, "\t\t\tfi\n");
	fprintf(f, "\t\t\techo $includes");

	for (pkg = project->packages; pkg != NULL; pkg = pkg->next)
	{
		for (check = pkg->checks; check != NULL; check = check->next)
		{
			if (check->cflags != NULL)
			{
				fprintf(f, " @%s@ ", check->cflags);
			}
		}
	}

	fprintf(f, "\n");
	fprintf(f, "\t\t\t;;\n\n");

	fprintf(f, "\t\t--libs)\n");
	fprintf(f, "\t\t\tlibdirs=-L@libdir@\n");
	fprintf(f, "\t\t\techo $libdirs");

	for (pkg = project->packages; pkg != NULL; pkg = pkg->next)
	{
		for (check = pkg->checks; check != NULL; check = check->next)
		{
			if (check->libs != NULL)
			{
				fprintf(f, " @%s@ ", check->libs);
			}
		}
	}

	fprintf(f, "\n");
	fprintf(f, "\t\t\t;;\n\n");

	fprintf(f, "\t\t*)\n");
	fprintf(f, "\t\t\techo \"${usage}\" 1>&2\n");
	fprintf(f, "\t\t\texit 1\n");
	fprintf(f, "\t\t\t;;\n");
	fprintf(f, "\tesac\n\n");

	fprintf(f, "shift\n");
	fprintf(f, "done\n");

	for (pkg = project->packages; pkg != NULL; pkg = pkg->next)
	{
		for (check = pkg->checks; check != NULL; check = check->next)
		{
			if (check->cflags != NULL)
			{
				fprintf(f, "\\\n");
				fprintf(f, "\t$(%s) ", check->cflags);
			}
		}
	}

	fprintf(f, "\n");

	fclose(f);
}

