/**
 * @file utils.c Utility functions
 * 
 * $Id: utils.c,v 1.10 2001/12/31 09:26:55 chipx86 Exp $
 *
 * @Copyright (C) 2000-2002 The GNUpdate Project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#include "genst.h"

#include <ctype.h>

static ProjectInfo *_currentProject = NULL;

int
getCharCount(const char *chars, char c)
{
	int count = 0;
	
	for (; *chars != '\0'; chars++)
	{
		if (*chars == c)
			count++;
	}

	return count;
}

int
charsToArray(const char *chars, char ***result)
{
	char buffer[4096];
	/* char *tok; */
	const char *c;
	char *d;
	int numTokens, curToken;
	char inQuotes;
	
	numTokens = getCharCount(chars, '"') / 2;
	
	if (numTokens == 0)
	{
		*result = NULL;
		return 0;
	}
	
	*result = (char **)malloc(numTokens * sizeof(char *));

	curToken = 0;
	inQuotes = 0;

	d = buffer;
	
	for (c = chars; *c != '\0'; c++)
	{
		if (*c == '"')
		{
			if (inQuotes)
			{
				if (d != buffer && *(d - 1) == '\\')
				{
					*d++ = *c;
				}
				else
				{
					*d = '\0';
					(*result)[curToken++] = strdup(buffer);
					strcpy(buffer, "");
					
					inQuotes = 0;
					d = buffer;
				}
			}
			else
				inQuotes = 1;
		}
		else
		{
			if (*c == ' ' && !inQuotes)
				continue;

			*d++ = *c;
		}
	}

	return numTokens;
}

char
isWhitespace(const char *chars)
{
	for (; *chars != '\0'; chars++)
	{
		if ((*chars != ' ')  && (*chars != '\t') &&
		    (*chars != '\n') && (*chars != '\r') &&
			(*chars != '\0'))
		{
			return 0;
		}
	}

	return 1;
}

char
isMenuSep(const char *item)
{
	if (isWhitespace(item))
		return 1;

	for (; *item != '\0'; item++)
	{
		if (*item != '-')
			return 0;
	}

	return 1;
}

char
inArray(const char **array, const char *item, int arraySize)
{
	int i;
	
	if (array == NULL || item == NULL)
		return 0;

	for (i = 0; i < arraySize; i++)
	{
		if (!strcmp(array[i], item))
			return 1;
	}

	return 0;
}

char
fileExists(const char *filename)
{
	struct stat statinfo;
	
	if (stat(filename, &statinfo) == 0)
		return 1;

	return 0;
}

void
touchFile(const char *dir, const char *filename)
{
	char *file;
	FILE *fp;

	file = (char *)malloc((strlen(dir) + strlen(filename) + 2) * sizeof(char));

	strcpy(file, dir);
	strcat(file, "/");
	strcat(file, filename);

	fp = fopen(file, "w");
	fclose(fp);

	free(file);
}

void
copyFile(const char *srcfile, const char *destfile)
{
	FILE *in, *out;
	char buffer[100];
	int i;

	if ((in = fopen(srcfile, "r")) == NULL)
		return;
	
	if ((out = fopen(destfile, "w")) == NULL)
	{
		fclose(in);
		return;
	}

	while ((i = fread(buffer, 1, 100, in)) != 0)
	{
		if (fwrite(buffer, 1, i, out) != i)
			break;
	}

	fclose(out);
	fclose(in);
}

void
appendFile(const char *srcfile, const char *destfile)
{
	FILE *in, *out;
	char buffer[100];
	int i;

	if ((in = fopen(srcfile, "r")) == NULL)
		return;

	if ((out = fopen(destfile, "a")) == NULL)
	{
		fclose(in);
		return;
	}

	while ((i = fread(buffer, 1, 100, in)) != 0)
	{
		if (fwrite(buffer, 1, i, out) != i)
			break;
	}

	fclose(out);
	fclose(in);
}

char *
stringToUpper(const char *str)
{
	char *newStr;
	int i = 0;
	int length = strlen(str);

	newStr = strdup(str);

	for (i = 0; i < length; i++)
		newStr[i] = toupper(newStr[i]);

	return newStr;
}

char *
fixProjectName(const char *str)
{
	char *newStr;
	char *c;

	newStr = strdup(str);

	for (c = newStr; *c != '\0'; c++)
	{
		if (*c == ' ' || *c == '/' || *c == '-')
			*c = '_';
	}

	return newStr;
}

void
setCurrentProject(ProjectInfo *project)
{
	_currentProject = project;
}

ProjectInfo *
getCurrentProject()
{
	return _currentProject;
}

char
confirmQuit()
{
	if (dialogYesNo(NULL, "Are you sure you want to quit?"))
		return 1;

	return 0;
}

void
quit()
{
	ProjectInfo *project = getCurrentProject();

	if (project != NULL)
		freeProjectInfo(project);

#ifdef WITH_LEAKBUG
	lbDumpLeaks();
#endif

	exit(0);
}

