/**
 * @file xml_lists.h XML list parser
 * 
 * $Id: xml_lists.c,v 1.11 2002/10/21 19:15:41 mhearn Exp $
 *
 * @Copyright (C) 2000-2002 The GNUpdate Project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public List
 * as published by the Free Software Foundation; either version 2
 * of the List, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public List for more details.
 *
 * You should have received a copy of the GNU General Public List
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#include "genst.h"

#include <libxml/parser.h>

static void
__startElement(void *userData, const char *name, const char **attrs)
{
	ListParserState *state = (ListParserState *)userData;
	
	if (!strcmp(name, "item"))
	{
		state->tag = LIST_NONE;
		state->isDefault = 0;
	}
	else if (!strcmp(name, "name"))        state->tag = LIST_NAME;
	else if (!strcmp(name, "description")) state->tag = LIST_DESCRIPTION;
	else if (!strcmp(name, "default"))     state->tag = LIST_DEFAULT;
}

static void
__endElement(void *userData, const char *name)
{
	ListParserState *state = (ListParserState *)userData;

	if (!strcmp(name, "item"))
	{
		ListItem *item;

		if (state->name == NULL)
		{
			fprintf(stderr, "XML Error: item must have a name!\n");
			exit(1);
		}
	
		item = newDialogListItem(state->name, state->description,
								 state->isDefault);

		free(state->name);
		state->name = NULL;

		if (state->description != NULL)
		{
			free(state->description);
			state->description = NULL;
		}
		
		dialogListAddItem(state->list, item);
	}
	
	state->tag = LIST_NONE;
}

static void
__characters(void *userData, const char *ch, int len)
{
	ListParserState *state = (ListParserState *)userData;
	
	char *data = (char *)malloc((len + 1) * sizeof(char));

	strncpy(data, ch, len);
	data[len] = '\0';

	if (isWhitespace(data))
	{
		free(data);
		return;
	}

	switch (state->tag)
	{
		case LIST_NONE:
			break;

		case LIST_NAME:
			if (state->name == NULL)
				state->name = strdup(data);
			else
			{
				char *newStr = (char *)malloc((strlen(state->name) +
											   strlen(data) + 1) *
											  sizeof(char));
				
				sprintf(newStr, "%s%s", state->name, data);

				free(state->name);
				state->name = newStr;
			}

			break;

		case LIST_DESCRIPTION:
			if (state->description == NULL)
				state->description = strdup(data);
			else
			{
				char *newStr = (char *)malloc((strlen(state->description) +
											   strlen(data) + 1) *
											  sizeof(char));
				
				sprintf(newStr, "%s%s", state->description, data);
				free(state->description);
				state->description = newStr;
			}
			break;

		case LIST_DEFAULT:
			if (!strcmp(data, "true"))
				state->isDefault = 1;
			else
				state->isDefault = 0;

			break;
	}
	
	free(data);
}

static xmlSAXHandler listHandler = {
	NULL,                                     /* internalSubset        */
	NULL,                                     /* isStandalone          */
	NULL,                                     /* hasInternalSubset     */
	NULL,                                     /* hasExternalSubset     */
	NULL,                                     /* resolveEntity         */
	NULL,                                     /* getEntity             */
	NULL,                                     /* entityDecl            */
	NULL,                                     /* notationDecl          */
	NULL,                                     /* attributeDecl         */
	NULL,                                     /* elementDecl           */
	NULL,                                     /* unparsedEntityDecl    */
	NULL,                                     /* setDocumentLocator    */
	NULL,                                     /* startDocument         */
	NULL,                                     /* endDocument           */
	(startElementSAXFunc)__startElement,      /* startElement          */
	(endElementSAXFunc)__endElement,          /* endElement            */
	NULL,                                     /* reference             */
	(charactersSAXFunc)__characters,          /* characters            */
	NULL,                                     /* ignorableWhitespace   */
	NULL,                                     /* processingInstruction */
	NULL,                                     /* comment               */
	(warningSAXFunc)xmlWarning,              /* warning               */
	(errorSAXFunc)xmlError,                  /* error                 */
	(fatalErrorSAXFunc)xmlFatalError        /* fatalError            */
};

void
xmlAddListItems(DialogList *list, const char *filename)
{
	ListParserState state;
	char *file;
	
	if (list == NULL || filename == NULL)
		return;
	
	file = (char *)malloc((strlen(data_dir) + strlen(filename) + 2) *
						  sizeof(char));
	
	strcpy(file, data_dir);
	strcat(file, "/");
	strcat(file, filename);

	state.list        = list;
	state.name        = NULL;
	state.description = NULL;
	
	parseXml(&listHandler, &state, file);

	free(file);
}

